
:autogenerated:

krotov.parallelization module
=============================

.. currentmodule:: krotov.parallelization

.. automodule:: krotov.parallelization
    :members: Consumer, FwPropStepTask, parallel_map_fw_prop_step
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Classes:

    .. autosummary::
        :nosignatures:

        Consumer
        FwPropStepTask

    Functions:

    .. autosummary::
        :nosignatures:

        parallel_map_fw_prop_step





    ``__all__``: :class:`Consumer <krotov.parallelization.Consumer>`, :class:`FwPropStepTask <krotov.parallelization.FwPropStepTask>`, :func:`parallel_map_fw_prop_step <krotov.parallelization.parallel_map_fw_prop_step>`



    Reference
    ---------